/* 
File : wfdb.i		I. Henry	October 17 2001
			Last revised:	2 March 2006 (by G. Moody)

SWIG interface file for WFDB
_______________________________________________________________________________
wfdb-bindings: SWIG (www.swig.org) wrappers for the WFDB library. Allows for 
reading and writing annotated waveforms (time series data) from a variety of 
computer languages.
Copyright (C) 2005 Isaac C. Henry

This library is free software; you can redistribute it and/or modify it under
the terms of the GNU Library General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your option) any
later version.

This library is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU Library General Public License for more
details.

You should have received a copy of the GNU Library General Public License along
with this library; if not, write to the Free Software Foundation, Inc., 59
Temple Place - Suite 330, Boston, MA 02111-1307, USA.

You may contact the author by e-mail (ihenry@physionet.org) or postal mail
(MIT Room E25-505A, Cambridge, MA 02139 USA).  For updates to this software,
please visit PhysioNet (http://www.physionet.org/).
_______________________________________________________________________________
*/

%module wfdb
%header %{
#include <wfdb/wfdb.h>
%}

#ifdef SWIGJAVA
%include wfdb-java/javadoc.i
#endif

/* Simple data types are declared in wfdb.h
typedef int	     WFDB_Sample;
typedef long 	     WFDB_Time;
typedef long	     WFDB_Date;
typedef double	     WFDB_Frequency;
typedef double	     WFDB_Gain;
typedef unsigned int WFDB_Group;
typedef unsigned int WFDB_Signal;
typedef unsigned int WFDB_Annotator;
*/

/* Structure definitions */
typedef struct WFDB_Siginfo {
    char *fname;
    char *desc;
    char *units;
    WFDB_Gain gain;
    WFDB_Sample initval;
    WFDB_Group group;
    int fmt;
    int spf;
    int bsize;
    int adcres;
    int adczero;
    int baseline;
    long nsamp;
    int cksum;
} WFDB_Siginfo;

%ignore WFDB_siginfo;

typedef struct WFDB_Calinfo {
    double low;
    double high;
    double scale;
    char *sigtype;
    char *units;
    int caltype;
} WFDB_Calinfo;

%ignore WFDB_calinfo;

typedef struct WFDB_Anninfo {
    char *name;	
    int stat;
} WFDB_Anninfo;

%ignore WFDB_anninfo;

/*
typedef struct WFDB_Annotation {
    WFDB_Time time;
    unsigned char anntyp;
    signed char subtyp;
    signed char chan;
    signed char num;
    char *aux;
} WFDB_Annotation;
*/

typedef struct WFDB_Annotation {
    WFDB_Time time;
    int anntyp;
    int subtyp;
    int chan;
    int num;
    char *aux;
} WFDB_Annotation;

%ignore WFDB_ann;

%include carrays.i
%array_class(WFDB_Sample, WFDB_SampleArray);
%array_class(WFDB_Siginfo, WFDB_SiginfoArray);
%array_class(WFDB_Anninfo, WFDB_AnninfoArray);

%include wfdb/ecgcodes.h
%include wfdb/wfdb.h
